==> apache-camel-3.21.5-src.zip: apache-camel-3.21.5/components/camel-as2/camel-as2-api/src/main/java/org/apache/camel/component/as2/api/entity/Importance.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.as2.api.entity;

public enum Importance {
    REQUIRED("required"),
    OPTIONAL("optional");

    private String importance;

    private Importance(String importance) {
        this.importance = importance;
    }

    public String getImportance() {
        return importance;
    }

    @Override
    public String toString() {
        return importance;
    }

    public static Importance get(String importance) {
        if (importance == null) {
            return null;
        }

        switch (importance.toLowerCase()) {
            case "required":
                return REQUIRED;
            case "optional":
                return OPTIONAL;
            default:
                return null;
        }
    }

}

==> apache-camel-4.10.8-src.zip: apache-camel-4.10.8/components/camel-as2/camel-as2-api/src/main/java/org/apache/camel/component/as2/api/entity/Importance.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.as2.api.entity;

public enum Importance {
    REQUIRED("required"),
    OPTIONAL("optional");

    private final String importance;

    private Importance(String importance) {
        this.importance = importance;
    }

    public String getImportance() {
        return importance;
    }

    @Override
    public String toString() {
        return importance;
    }

    public static Importance get(String importance) {
        if (importance == null) {
            return null;
        }

        switch (importance.toLowerCase()) {
            case "required":
                return REQUIRED;
            case "optional":
                return OPTIONAL;
            default:
                return null;
        }
    }

}
